@@ -87,7 +87,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_params();
+        let pp = self.post_with_manager(&self.manager);
 
         let object = if object.resource_version().is_some() {
             self.patch(object, objects).await?
@@ -113,7 +113,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_params();
+        let pp = self.post_with_manager(&self.manager);
 
         let object = if object.resource_version().is_some() {
             self.patch(object, objects).await?
@@ -138,7 +138,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_params();
+        let pp = self.post_with_manager(&self.manager);
 
         let object = if object.resource_version().is_some() {
             self.patch(object, objects).await?
@@ -149,6 +149,22 @@ impl Kubectl {
         Ok(object)
     }
 
+    pub async fn get_k_logs<K>(&self, object: &K) -> kube::Result<String>
+    where
+        K: kube::Resource + api::Log + de::DeserializeOwned,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let lp = self.log_params();
+        let objects = if let Some(namespace) = object.namespace() {
+            self.namespaced_api::<K>(&namespace)
+        } else {
+            self.api::<K>()
+        };
+
+        objects.logs(&name, &lp).await
+    }
+
     pub async fn list_pods_from_deployment<'a>(
         &self,
         deployment: &str,
