@@ -23,6 +23,7 @@ pub use k8s_openapi::api::core::v1 as corev1;
 pub use k8s_openapi::api::rbac::v1 as rbacv1;
 pub use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1 as apiextensionsv1;
 pub use k8s_openapi::apimachinery::pkg::apis::meta::v1 as metav1;
+pub use k8s_openapi::apimachinery::pkg::util::intstr;
 pub use k8s_openapi::Resource;
 
 pub use ext::ClusterRoleBindingExt;
@@ -37,6 +38,7 @@ pub use ext::NamespaceExt;
 pub use ext::PodSpecExt;
 pub use ext::PodTemplateSpecExt;
 pub use ext::PolicyRuleExt;
+pub use ext::ProbeExt;
 pub use ext::ResourceExt;
 pub use ext::RoleBindingExt;
 pub use ext::RoleExt;
